@@ -2,12 +2,11 @@
 // Copyright (c) 2012-2021 Snowflake Computing Inc. All right reserved.
 //
 
-#include <Python.h>
-#include <arrow/python/api.h>
+#include <string>
 #include "CArrowTableIterator.hpp"
 #include "SnowflakeType.hpp"
+#include "Python/Common.hpp"
 #include "Util/time.hpp"
-#include <string>
 
 namespace sf
 {
