@@ -5,9 +5,7 @@
 #ifndef PC_ICOLUMNCONVERTER_HPP
 #define PC_ICOLUMNCONVERTER_HPP
 
-#include <Python.h>
-#include <arrow/python/platform.h>
-#include <arrow/api.h>
+#include "Python/Common.hpp"
 
 namespace sf
 {
