@@ -17,7 +17,7 @@ from Cryptodome.Hash import SHA256
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import hashes
 
-from .constants import UTF8
+from .constants import UTF8, kilobyte
 
 logger = getLogger(__name__)
 
@@ -34,7 +34,7 @@ class SnowflakeFileUtil(object):
             Tuple of src's digest and src's size in bytes.
         """
         use_openssl_only = os.getenv("SF_USE_OPENSSL_ONLY", "False") == "True"
-        CHUNK_SIZE = 16 * 4 * 1024
+        CHUNK_SIZE = 64 * kilobyte
         if not use_openssl_only:
             m = SHA256.new()
         else:
@@ -74,7 +74,7 @@ class SnowflakeFileUtil(object):
         return BytesIO(compressed_data), len(compressed_data)
 
     @staticmethod
-    def compress_file_with_gzip(file_name, tmp_dir):
+    def compress_file_with_gzip(file_name: str, tmp_dir: str) -> Tuple[str, int]:
         """Compresses a file with GZIP.
 
         Args:
@@ -89,14 +89,14 @@ class SnowflakeFileUtil(object):
         logger.debug("gzip file: %s, original file: %s", gzip_file_name, file_name)
         with open(file_name, "rb") as fr:
             with gzip.GzipFile(gzip_file_name, "wb") as fw:
-                shutil.copyfileobj(fr, fw)
+                shutil.copyfileobj(fr, fw, length=64 * kilobyte)
         SnowflakeFileUtil.normalize_gzip_header(gzip_file_name)
 
         statinfo = os.stat(gzip_file_name)
         return gzip_file_name, statinfo.st_size
 
     @staticmethod
-    def normalize_gzip_header(gzip_file_name):
+    def normalize_gzip_header(gzip_file_name: str) -> None:
         """Normalizes GZIP file header.
 
         For consistent file digest, this removes creation timestamp and file name from the header.
