@@ -3,7 +3,7 @@
 #
 
 
-class UnicodeMixin(object):
+class UnicodeMixin:
     """Mixin class to handle defining the proper __str__/__unicode__ methods in Python 2 or 3."""
 
     def __str__(self):
